% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PURPOSE:          Script file for transforming predictions and data in BVARs 
%
% AUTHOR:           Mattias Villani, Research Department, Sveriges Riksbank and
%                   Department of Statistics, Stockholm University. 
%                   E-mail: mattias.villani@riksbank.se
%
% FIRST VERSION:    2005-02-23   
% LAST REVISED:     2007-09-17   
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

XOriginal=X; % Saves a copy of X before transforming.
p=length(varlabels);

if isnan(HistDecompShocks{1}) % Don't do the decomposition
    ComputeHistDecompShocks=0; 
else
    ComputeHistDecompShocks=1;
end

% Converting quarter-to-quarter predictions to annualized predictions
NDecompPeriods=size(HistDecompPreds,3);
NDecompIter=size(HistDecompPreds,1);
NDecomp=size(HistDecompPreds,4);
PredsByVar=zeros(niter,horizon);
HistDecompPredsByVar=zeros(NDecompIter,NDecompPeriods);

if LoadResultsFromFile==0
    for i=difference
        % Usual predictions
        if horizon>0
            for h=1:horizon
                PredsByVar(:,h)=preds(:,i,h);
            end
            PredsByVar=Diff2AnnualDiff(PredsByVar',repmat(X(T-season+2:T,i),1,niter),season)';
            for h=1:horizon
                preds(:,i,h)=PredsByVar(:,h);
            end

            % Naive forecasts
            NoChangeForecast(:,i)=Diff2AnnualDiff(NoChangeForecast(:,i),X(T-season+2:T,i),season);
            MeanForecast(:,i)=Diff2AnnualDiff(MeanForecast(:,i),X(T-season+2:T,i),season);
        end

        % Historical decomposition predictions
        if ComputeHistDecompShocks==1
            for DecompCounter=1:NDecomp
                for h=1:NDecompPeriods
                    HistDecompPredsByVar(:,h)=HistDecompPreds(:,i,h,DecompCounter);
                end
                HistDecompPredsByVar=Diff2AnnualDiff(HistDecompPredsByVar',[],season)';
                for h=1:NDecompPeriods
                    HistDecompPreds(:,i,h,DecompCounter)=HistDecompPredsByVar(:,h);
                end
            end
        else
            HistDecompPredsByVar=nan;
        end
    end
end

    
    
% % Converting quarter-to-quarter data to annualized data
Xyeardiff=X;
Xyeardiff(:,difference)=Diff2AnnualDiff(Xyeardiff(:,difference),[],season);
Z(:,difference)=Diff2AnnualDiff(Z(:,difference),[],season);

if ComputeHistDecompShocks==1
    DecompData=Xyeardiff(K+1:end,:); % Take away first K observations which are used as initial values in the prediction.
else
    DecompData=nan;
end

FutureData=Z(endest+1:end,:); % This is data beyond the estimation horizon, in annualized form.